==> nomadic_2025_01_17.zip: nomadic/resources/views/user/otp-verification-profile.blade.php <==
<div class="modal-dialog modal-lg">
    <div class="modal-content">
        <div class="modal-header">
          <h5 class="modal-title">OTP verification</h5>
          <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
        </div>
        <div class="modal-body">
            <div class="alert alert-danger errorMsgUpdt" style="display:none;"></div>
            <form id="otpForm" class="w-100">
                @csrf
                @if(isset($mobile))
                <span>{{__('Please input 6-digit code we just sent to')}} +*(***)*** {{$mobile}}</span>
                <input type="hidden" id="mobile_number" name="mobile" value="{{$amob}}" readonly>
                <div class="row mb-5 mt-4 d-block"  align="center">
                    <div class="col-md-6">
                        <div id="otp" class="inputs mt-2">
                            <input class="m-2 text-center form-control rounded otp-input" type="text" id="first" name="first" maxlength="1" />
                            <input class="m-2 text-center form-control rounded otp-input" type="text" id="second" name="second" maxlength="1" />
                            <input class="m-2 text-center form-control rounded otp-input" type="text" id="third" name="third" maxlength="1" />
                            <input class="m-2 text-center form-control rounded otp-input" type="text" id="fourth" name="fourth" maxlength="1" />
                            <input class="m-2 text-center form-control rounded otp-input" type="text" id="fifth" name="fifth" maxlength="1" />
                            <input class="m-2 text-center form-control rounded otp-input" type="text" id="sixth" name="sixth" maxlength="1" />
                        </div>
                        <div class="form-container">
                            <span>{{__('Didn’t get an SMS?')}}</span> <a data-type="mobile" class="send-otp pointer">{{__('Send again')}}</a>
                        </div>
                    </div>
                </div>
                @endif
                @if(isset($email))
                <span>{{__('Please input 6-digit code we just sent to')}} *******{{$email}}</span>
                <input type="hidden" id="email" name="email" value="{{$aemail}}" readonly>
                <div class="row mb-5 mt-4 d-block"  align="center">
                    <div class="col-md-6">
                        <div id="otp2" class="inputs mt-2">
                            <input class="m-2 text-center form-control rounded otp-input" type="text" id="eot1" name="eot1" maxlength="1" />
                            <input class="m-2 text-center form-control rounded otp-input" type="text" id="eot2" name="eot2" maxlength="1" />
                            <input class="m-2 text-center form-control rounded otp-input" type="text" id="eot3" name="eot3" maxlength="1" />
                            <input class="m-2 text-center form-control rounded otp-input" type="text" id="eot4" name="eot4" maxlength="1" />
                            <input class="m-2 text-center form-control rounded otp-input" type="text" id="eot5" name="eot5" maxlength="1" />
                            <input class="m-2 text-center form-control rounded otp-input" type="text" id="eot6" name="eot6" maxlength="1" />
                        </div>
                        <div class="form-container">
                            <span>{{__('Didn’t get an Email?')}}</span> <a  data-type="email" class="send-otp pointer">{{__('Send again')}}</a>
                            <div class="btnconter mt-3 mb-4">
                                <button class="btn" type="button" id="btn_otpverify">{{__('Verify')}}
                                    <div class="spinner-border text-primary spinner" role="status" style="display:none;vertical-align:text-top;"><span class="visually-hidden">{{__('Loading')}}...</span></div>
                                </button>
                            </div>
                        </div>
                    </div>
                </div>
                @endif
            </form>
        </div>
    </div>
</div>

==> nomadic_2025_07_19.zip: nomadic/resources/views/user/otp-verification-profile.blade.php <==
<div class="modal-dialog modal-lg">
    <div class="modal-content">
        <div class="modal-header">
          <h5 class="modal-title">OTP verification</h5>
          <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
        </div>
        <div class="modal-body">
            <div class="alert alert-danger errorMsgUpdt" style="display:none;"></div>
            <form id="otpForm" class="w-100">
                @csrf
                @if(isset($mobile))
                <span>{{__('Please input 6-digit code we just sent to')}} +*(***)*** {{$mobile}}</span>
                <input type="hidden" id="mobile_number" name="mobile" value="{{$amob}}" readonly>
                <div class="row mb-5 mt-4 d-block"  align="center">
                    <div class="col-md-6">
                        <div id="otp" class="inputs mt-2">
                            <input class="m-2 text-center form-control rounded otp-input" type="text" id="first" name="first" maxlength="1" />
                            <input class="m-2 text-center form-control rounded otp-input" type="text" id="second" name="second" maxlength="1" />
                            <input class="m-2 text-center form-control rounded otp-input" type="text" id="third" name="third" maxlength="1" />
                            <input class="m-2 text-center form-control rounded otp-input" type="text" id="fourth" name="fourth" maxlength="1" />
                            <input class="m-2 text-center form-control rounded otp-input" type="text" id="fifth" name="fifth" maxlength="1" />
                            <input class="m-2 text-center form-control rounded otp-input" type="text" id="sixth" name="sixth" maxlength="1" />
                        </div>
                        <div class="form-container">
                            <span>{{__('Didn’t get an SMS?')}}</span> <a data-type="mobile" class="send-otp pointer">{{__('Send again')}}</a>
                        </div>
                    </div>
                </div>
                @endif
                @if(isset($email))
                <span>{{__('Please input 6-digit code we just sent to')}} *******{{$email}}</span>
                <input type="hidden" id="email" name="email" value="{{$aemail}}" readonly>
                <div class="row mb-5 mt-4 d-block"  align="center">
                    <div class="col-md-6">
                        <div id="otp2" class="inputs mt-2">
                            <input class="m-2 text-center form-control rounded otp-input" type="text" id="eot1" name="eot1" maxlength="1" />
                            <input class="m-2 text-center form-control rounded otp-input" type="text" id="eot2" name="eot2" maxlength="1" />
                            <input class="m-2 text-center form-control rounded otp-input" type="text" id="eot3" name="eot3" maxlength="1" />
                            <input class="m-2 text-center form-control rounded otp-input" type="text" id="eot4" name="eot4" maxlength="1" />
                            <input class="m-2 text-center form-control rounded otp-input" type="text" id="eot5" name="eot5" maxlength="1" />
                            <input class="m-2 text-center form-control rounded otp-input" type="text" id="eot6" name="eot6" maxlength="1" />
                        </div>
                        <div class="form-container">
                            <span>{{__('Didn’t get an Email?')}}</span> <a  data-type="email" class="send-otp pointer">{{__('Send again')}}</a>
                            <div class="btnconter mt-3 mb-4">
                                <button class="btn btn-primary" type="button" id="btn_otpverify">{{__('Submit')}}
                                    <div class="spinner-border text-primary spinner" role="status" style="display:none;vertical-align:text-top;"><span class="visually-hidden">{{__('Loading')}}...</span></div>
                                </button>
                            </div>
                        </div>
                    </div>
                </div>
                @endif
            </form>
        </div>
    </div>
</div>
